# clibf

## Install it from PyPi

```
pip install clibf
```

## Install it from GitHub

```
pip install git+https://github.com/donno2048/bf-interpreter
```

## Execute a brainfuck file

```
clibf -f my_bf_script.b
```

## Execute a string as a brainfuck code

```
clibf -s "my_bf_string"
```

## Execute a file with a GUI

```
clibf -g
```
